@@ -1,5 +1,6 @@
 import pymysql
 from pymysql import cursors
+from pymyorm.batch import Batch
 
 
 class Connection(object):
@@ -60,6 +61,17 @@ class Connection(object):
         except Exception as e:
             raise e
 
+    def batch(self, sql):
+        try:
+            if self.__debug:
+                print(f"batch sql: {sql}")
+            self.__conn.autocommit(self.__autocommit)
+            cursor = self.__conn.cursor()
+            cursor.execute(sql)
+            return Batch(cursor)
+        except Exception as e:
+            raise e
+
     def insert(self, sql):
         try:
             if self.__debug:
