@@ -1,10 +1,12 @@
 from pymyorm.local import local
+import pprint
 
 
 class Model(object):
     tablename = None
     primary_key = 'id'
     datetime_fields = []
+    decimal_fields = []
 
     def __init__(self, **kwargs) -> None:
         self.__conn = local.conn
@@ -16,6 +18,7 @@ class Model(object):
         self.__where = []
         self.__order = {}
         self.__group = {}
+        self.__having = ''
         self.__offset = ''
         self.__limit = ''
         self.__alias = ''
@@ -39,10 +42,10 @@ class Model(object):
             value = self.__old_fields[name]
         else:
             raise Exception(f"object has no attribute '{name}'")
-        if name in self.datetime_fields:
-            return value.strftime('%Y-%m-%d %H:%M:%S')
-        else:
-            return value
+        return value
+
+    def __setitem__(self, key, value):
+        self.__dict__['_Model__new_fields'][key] = value
 
     def __getitem__(self, item):
         return getattr(self, item)
@@ -59,6 +62,13 @@ class Model(object):
         fields.update(self.__new_fields)
         return str(fields)
 
+    def print(self):
+        fields = {}
+        fields.update(self.__old_fields)
+        fields.update(self.__new_fields)
+        pp = pprint.PrettyPrinter(indent=2)
+        pp.pprint(fields)
+
     @classmethod
     def find(cls):
         return cls()
@@ -79,6 +89,14 @@ class Model(object):
         sql = f"truncate table `{model.__class__.tablename}`"
         return model.__conn.execute(sql.strip())
 
+    @classmethod
+    def schema(cls):
+        model = cls()
+        database = model.__conn._Connection__config['database']
+        table = model.tablename
+        sql = f"select column_name,column_key,data_type,extra,column_comment from information_schema.columns where table_schema='{database}' and table_name='{table}'"
+        return model.__conn.fetchall(sql)
+
     def save(self):
         if self.__old_fields.get(self.__class__.primary_key) is None:
             fields = ','.join([f"`{item}`" for item in self.__new_fields.keys()])
@@ -88,7 +106,8 @@ class Model(object):
             sql = f"insert into `{self.__class__.tablename}`({fields}) values({values})"
             self.__sql = sql
             last_insert_id = self.__conn.insert(sql)
-            self.__new_fields[self.__class__.primary_key] = last_insert_id
+            if self.__class__.primary_key not in self.__new_fields:
+                self.__new_fields[self.__class__.primary_key] = last_insert_id
         else:
             update_str = ','.join([f"`{k}`='{v}'" for (k, v) in self.__new_fields.items()])
             sql = f"update `{self.__class__.tablename}` set {update_str} where `{self.__class__.primary_key}`='{self.__old_fields.get(self.__class__.primary_key)}'"
@@ -149,6 +168,8 @@ class Model(object):
         sql = ''
         if self.__group:
             sql += f"group by {self.__group} "
+        if self.__having:
+            sql += f"having {self.__having}"
         if self.__order:
             sql += f"order by {self.__order} "
         if self.__limit:
@@ -175,35 +196,54 @@ class Model(object):
             sql += f"{join['type']} join `{join['table']}` as `{join['alias']}` on {on} "
         return sql
 
-    def one(self):
+    def one(self, raw=False):
         if self.__class__.tablename is None:
             raise Exception('missing table name')
 
         self.__limit = 1
         sql = self.sql()
 
-        one = self.__class__()
-        res = self.__conn.fetchone(sql)
-        if res is None:
+        one = self.__conn.fetchone(sql)
+        if one is None:
             return None
-        for (k, v) in res.items():
-            one.__old_fields[k] = v
-        return one
+        if self.datetime_fields or self.decimal_fields:
+            for k, v in one.items():
+                if k in self.datetime_fields:
+                    one[k] = v.strftime('%Y-%m-%d %H:%M:%S')
+                elif k in self.decimal_fields:
+                    one[k] = float(v)
+        if raw:
+            return one
 
-    def all(self):
+        res = self.__class__()
+        for (k, v) in one.items():
+            res.__old_fields[k] = v
+        return res
+
+    def all(self, raw=False):
         if self.__class__.tablename is None:
             raise Exception('missing table name')
         sql = self.sql()
-        res = self.__conn.fetchall(sql)
-        if res is None:
+        all = self.__conn.fetchall(sql)
+        if all is None:
             return []
-        all = []
-        for one in res:
+        if self.datetime_fields or self.decimal_fields:
+            for one in all:
+                for k, v in one.items():
+                    if k in self.datetime_fields:
+                        one[k] = v.strftime('%Y-%m-%d %H:%M:%S')
+                    elif k in self.decimal_fields:
+                        one[k] = float(v)
+        if raw:
+            return all
+
+        res = []
+        for one in all:
             item = self.__class__()
             for (k, v) in one.items():
                 item.__old_fields[k] = v
-            all.append(item)
-        return all
+            res.append(item)
+        return res
 
     def alias(self, alias):
         self.__alias = alias
@@ -223,11 +263,10 @@ class Model(object):
                 if len(arr) == 2:
                     pass
                 if len(arr) == 3:
-                    if arr[1] != 'as':
+                    if arr[1].lower() != 'as':
                         raise Exception(f'select statement error: {arg}')
                     del arr[1]
                 field = f"{arr[0]} as `{arr[1]}`"
-                print(arr)
             else:
                 if arg.find('.'):
                     temp = []
@@ -310,6 +349,12 @@ class Model(object):
         self.__group = group
         return self
 
+    def having(self, *args):
+        if len(args) != 3:
+            raise Exception(f'having statement error')
+        self.__having = f"`{args[0]}` {args[1]} {args[2]}"
+        return self
+
     def offset(self, offset):
         self.__offset = offset
         return self
@@ -320,78 +365,104 @@ class Model(object):
 
     def count(self, field=None):
         if self.__class__.tablename is None:
-            raise('missing table name')
+            raise Exception('missing table name')
         sql = "select "
         if field is not None:
-            if field == '*':
-                sql += "count(*) "
+            if field.find('.'):
+                temp = []
+                for v in field.split('.'):
+                    if v == '*':
+                        temp.append(v)
+                    else:
+                        temp.append(f"`{v}`")
+                field = '.'.join(temp)
             else:
-                sql += f"count(`{field}`) "
+                if field != '*':
+                    field = f"`{field}`"
+            sql += f"count({field}) "
         else:
-            sql += "count(*) "
+            sql += f"count(*) "
         sql += f"from `{self.__class__.tablename}` "
+        if self.__alias:
+            sql += f"as `{self.__alias}` "
+        sql += self.__build_join_sql()
         sql += self.__build_where_sql()
         sql += self.__build_other_sql()
         self.__sql = sql.strip()
         return self.__conn.count(self.__sql)
 
-    def min(self, field):
+    def __build_simple_sql(self, field, func=''):
         if self.__class__.tablename is None:
-            raise('missing table name')
-        sql = f"select min(`{field}`) from `{self.__class__.tablename}` "
+            raise Exception('missing table name')
+
+        if field is None:
+            raise Exception('field is None')
+
+        sql = "select "
+        if field.find('.'):
+            temp = []
+            for v in field.split('.'):
+                temp.append(f"`{v}`")
+            field = '.'.join(temp)
+        else:
+            field = f"`{field}`"
+        if func:
+            sql += f"{func}({field}) "
+        else:
+            sql += f"{field} "
+        sql += f"from `{self.__class__.tablename}` "
+        if self.__alias:
+            sql += f"as `{self.__alias}` "
+        sql += self.__build_join_sql()
         sql += self.__build_where_sql()
         sql += self.__build_other_sql()
-        self.__sql = sql.strip()
+        return sql.strip()
+
+    def min(self, field):
+        self.__sql = self.__build_simple_sql(field, 'min')
         return self.__conn.min(self.__sql)
 
     def max(self, field):
-        if self.__class__.tablename is None:
-            raise('missing table name')
-        sql = f"select max(`{field}`) from `{self.__class__.tablename}` "
-        sql += self.__build_where_sql()
-        sql += self.__build_other_sql()
-        self.__sql = sql.strip()
+        self.__sql = self.__build_simple_sql(field, 'max')
         return self.__conn.max(self.__sql)
 
     def average(self, field):
-        if self.__class__.tablename is None:
-            raise('missing table name')
-        sql = f"select avg(`{field}`) from `{self.__class__.tablename}` "
-        sql += self.__build_where_sql()
-        sql += self.__build_other_sql()
-        self.__sql = sql.strip()
+        self.__sql = self.__build_simple_sql(field, 'avg')
         return self.__conn.average(self.__sql)
 
     def exists(self):
         if self.__class__.tablename is None:
-            raise('missing table name')
-        sql = f"select exists(select `{self.__class__.primary_key}` from `{self.__class__.tablename}` "
-        sql += self.__build_where_sql()
-        sql += self.__build_other_sql()
-        sql = sql.strip()
-        sql += f")"
-        self.__sql = sql
-        return self.__conn.exists(self.__sql)
+            raise Exception('missing table name')
+        sql = f"select exists({self.sql()})"
+        self.__sql = sql.strip()
+        return self.__conn.exists(sql)
 
     def column(self, field):
-        if self.__class__.tablename is None:
-            raise('missing table name')
-        sql = f"select `{field}` from `{self.__class__.tablename}` "
-        sql += self.__build_where_sql()
-        sql += self.__build_other_sql()
-        self.__sql = sql.strip()
+        self.__sql = self.__build_simple_sql(field)
         result = self.__conn.column(self.__sql)
-        return [item[field] for item in result]
+        res = []
+        for item in result:
+            for _, v in item.items():
+                res.append(v)
+        return res
 
     def scalar(self, field):
-        if self.__class__.tablename is None:
-            raise('missing table name')
         self.__limit = 1
-        sql = f"select `{field}` from `{self.__class__.tablename}` "
-        sql += self.__build_where_sql()
-        sql += self.__build_other_sql()
-        self.__sql = sql.strip()
+        self.__sql = self.__build_simple_sql(field)
         result = self.__conn.scalar(self.__sql)
         if result is None:
             return None
-        return result[field]
+        for _, v in result.items():
+            return v
+
+    def batch(self, size=100, raw=False):
+        if self.__class__.tablename is None:
+            raise Exception('missing table name')
+        total = self.count()
+        sql = self.sql()
+        batch = self.__conn.batch(sql)
+        batch.raw(raw=raw)
+        batch.size(size=size)
+        batch.total(total=total)
+        batch.model(self)
+        return batch
