@@ -4,5 +4,6 @@ db = {
     'user': 'root',
     'password': 'password',
     'database': 'test',
-    'charset': 'utf8'
+    'charset': 'utf8',
+    'debug': True
 }
