@@ -7,12 +7,12 @@ from models.admin_auth import AdminAuth
 
 if __name__ == '__main__':
 
-    Database().connect(**db)
+    Database.connect(**db)
 
     # case 1
     all = Admin.find().select('a.*').alias('a') \
         .join(table=AdminRole.tablename, alias='r', on='a.role = r.id') \
-        .where('r.name', '=', '运营专员') \
+        .where('r.name', '=', 'role1') \
         .where('a.lock', '=', 0) \
         .all()
     for one in all:
@@ -38,7 +38,7 @@ if __name__ == '__main__':
     # all = Admin.find().select('username', 'a.role').alias('a') \
     #     .join(table=AdminRole.tablename, alias='r', on='a.role=r.id') \
     #     .join(table=AdminAuth.tablename, alias='t', on='t.role=r.id') \
-    #     .where('t.action', '=', 300) \
+    #     .where('t.action', '=', 'play') \
     #     .all()
     # for one in all:
     #     print(one)
